==> bladerf-2023.02-2-aarch64.pkg.tar.xz: usr/share/doc/libbladeRF/html/search/all_13.js <==
var searchData=
[
  ['tamer_20mode_0',['VCTCXO Tamer Mode',['../group___f_n___v_c_t_c_x_o___t_a_m_e_r.html',1,'']]],
  ['tee_20control_1',['Bias Tee Control',['../group___f_n___b_l_a_d_e_r_f2___b_i_a_s___t_e_e.html',1,'']]],
  ['tees_2',['Bias tees',['../relnotes_2_0.html#relnotes_2_0_feats_hw_biastee',1,'']]],
  ['temperature_3',['RFIC temperature',['../relnotes_2_0.html#relnotes_2_0_feats_hw_temperature',1,'']]],
  ['the_20libbladerf_20api_4',['Significant changes to the libbladeRF API',['../relnotes_2_0.html#relnotes_2_0_api',1,'']]],
  ['timestamp_5',['timestamp',['../structbladerf__image.html#a465bef81f6478756e5443025b1f2ddfa',1,'bladerf_image::timestamp'],['../structbladerf__metadata.html#ae6fe2699806587b6bb21c5c44cc84c37',1,'bladerf_metadata::timestamp']]],
  ['to_20the_20libbladerf_20api_6',['Significant changes to the libbladeRF API',['../relnotes_2_0.html#relnotes_2_0_api',1,'']]],
  ['todo_20list_7',['Todo List',['../todo.html',1,'']]],
  ['trigger_20control_8',['Trigger Control',['../group___f_n___t_r_i_g_g_e_r___c_o_n_t_r_o_l.html',1,'']]],
  ['triggers_9',['Triggers',['../group___f_n___t_r_i_g.html',1,'']]],
  ['trim_20dac_10',['VCTCXO Trim DAC',['../group___f_n___v_c_t_c_x_o___t_r_i_m___d_a_c.html',1,'']]],
  ['tuning_11',['Scheduled Tuning',['../group___f_n___s_c_h_e_d_u_l_e_d___t_u_n_i_n_g.html',1,'']]],
  ['tuning_20bladerf1_12',['Frequency tuning (bladeRF1)',['../tuning.html',1,'']]],
  ['tuning_20mode_13',['Tuning Mode',['../group___f_n___t_u_n_i_n_g___m_o_d_e.html',1,'']]],
  ['tx_20bursts_14',['Synchronous Interface: Scheduled TX bursts',['../sync_tx_meta_bursts.html',1,'']]],
  ['tx1_5frfic_5fport_15',['tx1_rfic_port',['../structbladerf__rf__switch__config.html#ad9bc7ecaf242c514479e16a83ea9fb68',1,'bladerf_rf_switch_config']]],
  ['tx1_5fspdt_5fport_16',['tx1_spdt_port',['../structbladerf__rf__switch__config.html#ac9b4fb951c2b556385d4ba982a0efa3d',1,'bladerf_rf_switch_config']]],
  ['tx2_5frfic_5fport_17',['tx2_rfic_port',['../structbladerf__rf__switch__config.html#a8c5ad31956856ea17b57c550d6333cf7',1,'bladerf_rf_switch_config']]],
  ['tx2_5fspdt_5fport_18',['tx2_spdt_port',['../structbladerf__rf__switch__config.html#a5d2ed05247b6c31a9781aac8f7d2c486',1,'bladerf_rf_switch_config']]],
  ['tx_5flpf_5fi_19',['tx_lpf_i',['../structbladerf__lms__dc__cals.html#a11fc4135a30e8a25d04bbccdd1b1aba4',1,'bladerf_lms_dc_cals']]],
  ['tx_5flpf_5fq_20',['tx_lpf_q',['../structbladerf__lms__dc__cals.html#a127274913d678a9324879ecfbf35c81e',1,'bladerf_lms_dc_cals']]],
  ['type_21',['type',['../structbladerf__image.html#af9f42cdfa1fceaec8db32c7ff98a96bf',1,'bladerf_image']]],
  ['typedefs_22',['typedefs',['../relnotes_2_0.html#relnotes_2_0_api_typedefs',1,'Common parameter types now have typedefs'],['../todo.html#_todo000002',1,'Common parameter types now have typedefs']]],
  ['types_20now_20have_20typedefs_23',['types now have typedefs',['../relnotes_2_0.html#relnotes_2_0_api_typedefs',1,'Common parameter types now have typedefs'],['../todo.html#_todo000002',1,'Common parameter types now have typedefs']]]
];

==> bladerf-2024.05-1-aarch64.pkg.tar.xz: usr/share/doc/libbladeRF/html/search/all_13.js <==
var searchData=
[
  ['tamer_20mode_0',['VCTCXO Tamer Mode',['../group___f_n___v_c_t_c_x_o___t_a_m_e_r.html',1,'']]],
  ['tee_20control_1',['Bias Tee Control',['../group___f_n___b_l_a_d_e_r_f2___b_i_a_s___t_e_e.html',1,'']]],
  ['tees_2',['Bias tees',['../relnotes_2_0.html#relnotes_2_0_feats_hw_biastee',1,'']]],
  ['temperature_3',['RFIC temperature',['../relnotes_2_0.html#relnotes_2_0_feats_hw_temperature',1,'']]],
  ['the_20libbladerf_20api_4',['Significant changes to the libbladeRF API',['../relnotes_2_0.html#relnotes_2_0_api',1,'']]],
  ['timestamp_5',['timestamp',['../structbladerf__metadata.html#ae6fe2699806587b6bb21c5c44cc84c37',1,'bladerf_metadata::timestamp'],['../structbladerf__image.html#a465bef81f6478756e5443025b1f2ddfa',1,'bladerf_image::timestamp']]],
  ['to_20the_20libbladerf_20api_6',['Significant changes to the libbladeRF API',['../relnotes_2_0.html#relnotes_2_0_api',1,'']]],
  ['todo_20list_7',['Todo List',['../todo.html',1,'']]],
  ['trigger_20control_8',['Trigger Control',['../group___f_n___t_r_i_g_g_e_r___c_o_n_t_r_o_l.html',1,'']]],
  ['triggers_9',['Triggers',['../group___f_n___t_r_i_g.html',1,'']]],
  ['trim_20dac_10',['VCTCXO Trim DAC',['../group___f_n___v_c_t_c_x_o___t_r_i_m___d_a_c.html',1,'']]],
  ['tuning_11',['Scheduled Tuning',['../group___f_n___s_c_h_e_d_u_l_e_d___t_u_n_i_n_g.html',1,'']]],
  ['tuning_20bladerf1_12',['Frequency tuning (bladeRF1)',['../tuning.html',1,'']]],
  ['tuning_20mode_13',['Tuning Mode',['../group___f_n___t_u_n_i_n_g___m_o_d_e.html',1,'']]],
  ['tx_20bursts_14',['Synchronous Interface: Scheduled TX bursts',['../sync_tx_meta_bursts.html',1,'']]],
  ['tx1_5frfic_5fport_15',['tx1_rfic_port',['../structbladerf__rf__switch__config.html#ad9bc7ecaf242c514479e16a83ea9fb68',1,'bladerf_rf_switch_config']]],
  ['tx1_5fspdt_5fport_16',['tx1_spdt_port',['../structbladerf__rf__switch__config.html#ac9b4fb951c2b556385d4ba982a0efa3d',1,'bladerf_rf_switch_config']]],
  ['tx2_5frfic_5fport_17',['tx2_rfic_port',['../structbladerf__rf__switch__config.html#a8c5ad31956856ea17b57c550d6333cf7',1,'bladerf_rf_switch_config']]],
  ['tx2_5fspdt_5fport_18',['tx2_spdt_port',['../structbladerf__rf__switch__config.html#a5d2ed05247b6c31a9781aac8f7d2c486',1,'bladerf_rf_switch_config']]],
  ['tx_5flpf_5fi_19',['tx_lpf_i',['../structbladerf__lms__dc__cals.html#a11fc4135a30e8a25d04bbccdd1b1aba4',1,'bladerf_lms_dc_cals']]],
  ['tx_5flpf_5fq_20',['tx_lpf_q',['../structbladerf__lms__dc__cals.html#a127274913d678a9324879ecfbf35c81e',1,'bladerf_lms_dc_cals']]],
  ['type_21',['type',['../structbladerf__image.html#af9f42cdfa1fceaec8db32c7ff98a96bf',1,'bladerf_image']]],
  ['typedefs_22',['typedefs',['../relnotes_2_0.html#relnotes_2_0_api_typedefs',1,'Common parameter types now have typedefs'],['../todo.html#_todo000002',1,'Common parameter types now have typedefs']]],
  ['types_20now_20have_20typedefs_23',['types now have typedefs',['../relnotes_2_0.html#relnotes_2_0_api_typedefs',1,'Common parameter types now have typedefs'],['../todo.html#_todo000002',1,'Common parameter types now have typedefs']]]
];
